<?php
namespace Backend\Controller;

use Backend\Controller\BackendController;
use Common\Respository\ProblemRespository;

class ProblemController extends BackendController{

	/**
	 * 初始化仓储和模型
	 * @时间: 2017年10月26日11:41:25
	 * @author: Guopeng
	 * @return mixed
	 */
	public function _initialize(){
		parent::_initialize();
		$this->model = new \Backend\Model\CommonProblemModel();
		$this->respository = new ProblemRespository($this->model);
	}
	
	/**
	 * 问题列表
	 * @时间: 2017年10月26日11:41:25
	 * @author: Guopeng
	 * @return mixed
	 */
	public function index(){
		//表头，排序相关数据
		$th = $this->model->getSortable();
		//获取表头里面真正有排序的字段
		$sorted = $this->model->getSortableField($th);
		//未加排序前缀的表头
		$th_raw = array_keys($this->model->sortable);
		//获取筛选字段的需要的数据,筛选所需要的字段
		$search = $this->model->getFillData()->getSearchable();
		//获取需要展示的字段，列表的表头
		$field = implode(',',array_keys($this->model->sortable));
		//获取所有的数据
		$data = $this->respository->finder($field);
		//处理分页参数问题
		$current_page = empty(request()['p']) ? 1 : request()['p'];
		$this->assign([
			'search' => $search,
			'th' => $th,
			'th_count' => count($th),    //表格列数
			'th_raw' => $th_raw,
			'sorted' => $sorted,    //真正可以排序的字段
			'data' => $data['data'],
			'sum_pages' => $data['sumPages'],
			'total' => $data['total'],
			'current_page' => $current_page,
			'per_page' => $data['perPage'],
			'pages' => $data['show'],
			'request' => request()
		]);
		if(IS_AJAX){
			return $this->fetch();
		}else{
			$this->display();
		}
	}
	
	/**
	 * 新增问题页面
	 * @时间: 2017年10月26日11:41:25
	 * @author: Guopeng
	 */
	public function create(){
		//产品分类数据
		$problem_type = (new \Backend\Model\CommonProblemTypeModel())->getType("id as k,name as v",1);
		$this->assign([
			'product_type' => $problem_type,
			'state' => [1 => '显示',0 => '不显示']    //账号状态
		]);
		$this->display();
	}
	
	/**
	 * 新增问题操作
	 * @时间: 2017年10月26日11:41:25
	 * @author: Guopeng
	 */
	public function recording(){
		$request = request();
		$request['problem_content'] = $_POST['problem_content'];
		if(empty($request['problem_content'])){
			$msg = "文章内容不能为空！";
			if(IS_AJAX){
				$this->error($msg,'',true);
			}else{
				$this->error($msg);
			}
		}
		$res = $this->respository->create($request);
		//返回结果
		if($res === false){
			$msg = $this->model->getError().'添加失败，请重试！';
			if(IS_AJAX){
				$this->error($msg,'',true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = '添加成功';
			$url = U('Problem/index');
			if(IS_AJAX){
				$this->success($msg,$url,true);
			}else{
				$this->success($msg,$url);
			}
		}
	}

	/**
	 * 问题更新页面
	 * @时间: 2017年10月26日11:41:25
	 * @author: Guopeng
	 */
	public function update(){
		$id = request()['id'] + 0;
		$entity = $this->respository->firstOrFalse(['id' => ['eq',$id]]);
		if(!$entity){
			$this->error('参数有误，没有该问题的相关信息！');
			die;
		}
		//产品分类数据
		$product_type = (new \Backend\Model\CommonProblemTypeModel())->getType("id as k,name as v",1);
		$this->assign([
			'entity' => $entity,
			'product_type' => $product_type,
			'state' => [1 => '显示',0 => '不显示']    //账号状态
		]);
		$this->display();
	}
	
	/**
	 * 更新问题信息
	 * @时间: 2017年10月26日11:41:25
	 * @author: Guopeng
	 */
	public function store(){
		//取参数
		$request = request();
		$id = $request['id'];
		unset($request['id']);
		$data = $request;
		$data['problem_content'] = $_POST['problem_content'];
		if(empty($request['problem_content'])){
			$msg = "文章内容不能为空！";
			if(IS_AJAX){
				$this->error($msg,'',true);
			}else{
				$this->error($msg);
			}
		}
		//更新操作
		$res = $this->respository->update($data,$id,'id');
		//返回结果
		if($res === false){
			$msg = $this->model->getError().'更新问题失败，请重试！';
			if(IS_AJAX){
				$this->error($msg,'',true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = '更新问题成功';
			$url = U('Problem/index');
			if(IS_AJAX){
				$this->success($msg,$url,true);
			}else{
				$this->success($msg,$url);
			}
		}
	}

	/**
	 * 隐藏问题
	 * @时间: 2017年10月26日11:41:25
	 * @author: Guopeng
	 */
	public function disable(){
		//取参数
		$request = request();
		$id = $request['id'];
		//修改状态为禁用
		$data['state'] = 0;
		//更新操作
		$res = M('common_problem')->where(['id' => ['eq',$id]])->setField($data);
		//返回结果
		if($res === false){
			$msg = $this->model->getError().'，隐藏问题失败，请重试！';
			if(IS_AJAX){
				$this->error($msg,'',true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = '隐藏问题成功';
			if(IS_AJAX){
				$this->success($msg,'',true);
			}else{
				$this->success($msg);
			}
		}
	}

	/**
	 * 显示问题
	 * @时间: 2017年10月26日11:41:25
	 * @author: Guopeng
	 */
	public function enable(){
		//取参数
		$request = request();
		$id = $request['id'];
		//修改状态为禁用
		$data['state'] = 1;
		//更新操作
		$res = M('common_problem')->where(['id' => ['eq',$id]])->setField($data);
		//返回结果
		if($res === false){
			$msg = $this->model->getError().'，显示问题失败，请重试！';
			if(IS_AJAX){
				$this->error($msg,'',true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = '显示问题成功';
			if(IS_AJAX){
				$this->success($msg,'',true);
			}else{
				$this->success($msg);
			}
		}
	}
	
	/**
	 * 问题详情页面
	 * @时间: 2017年10月26日11:41:25
	 * @author: Guopeng
	 */
	public function details(){
		//获取会员id
		$id = request()['id'] + 0;
		//获取会员信息
		$entity = $this->respository->firstOrFalse(['id' => ['eq',$id]]);
		if(!$entity){
			$this->error('参数有误，没有该会员的相关信息！');
			die;
		}
		//产品分类数据
		$product_type = (new \Backend\Model\CommonProblemTypeModel())->getType("id as k,name as v",1);
		$this->assign([
			'entity' => $entity,
			'id' => $id,
			'state' => [1 => '显示',0 => '不显示'],    //账号状态
			'product_type' => $product_type,
			'state' => $this->model->searchable['state']['data']
		]);
		$this->display();
	}
	
	/**
	 * 删除问题
	 * @时间: 2017年10月26日11:41:25
	 * @author: Guopeng
	 * @return mixed
	 */
	public function erase(){
		//取参数
		$request = request();
		$id = $request['id'];
		//删除业务操作
		$res = $this->respository->delete(['id' => ['eq',$id]]);
		//返回结果
		if($res === false){
			$msg = $this->model->getError();
			if(IS_AJAX){
				$this->error($msg,'',true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = '删除成功';
			if(IS_AJAX){
				$this->success($msg,'',true);
			}else{
				$this->success($msg);
			}
		}
	}
}