<?php
namespace Backend\Controller;

use Backend\Controller\BackendController;
use Common\Respository\ProblemTypeRespository;

class ProblemTypeController extends BackendController{

	/**
	 * | 初始化仓储和模型
	 * | @时间: 2017年10月24日 下午6:04:54
	 * | @author: Guopeng
	 */
	public function _initialize(){
		parent::_initialize();
		$this->model = new \Backend\Model\CommonProblemTypeModel();
		$this->respository = new ProblemTypeRespository($this->model);
	}
	
	/**
	 * 问题分类列表
	 * @时间: 2017年10月24日 下午6:04:54
	 * @author: Guopeng
	 * @return mixed
	 */
	public function index(){
		//表头，排序相关数据
		$th = $this->model->getSortable();
		//获取表头里面真正有排序的字段
		$sorted = $this->model->getSortableField($th);
		//未加排序前缀的表头
		$th_raw = array_keys($this->model->sortable);
		//获取筛选字段的需要的数据,筛选所需要的字段
		$search = $this->model->getFillData()->getSearchable();
		//获取需要展示的字段，列表的表头
		$field = implode(',',array_keys($this->model->sortable));
		//获取所有的数据
		$data = $this->respository->finder($field);
		//处理分页参数问题
		$current_page = empty(request()['p']) ? 1 : request()['p'];
		$this->assign([
			'search' => $search,
			'th' => $th,
			'th_count' => count($th),    //表格列数
			'th_raw' => $th_raw,
			'sorted' => $sorted,    //真正可以排序的字段
			'data' => $data['data'],
			'sum_pages' => $data['sumPages'],
			'total' => $data['total'],
			'current_page' => $current_page,
			'per_page' => $data['perPage'],
			'pages' => $data['show'],
			'request' => request()
		]);
		if(IS_AJAX){
			return $this->fetch();
		}else{
			$this->display();
		}
	}

	/**
	 * 添加问题分类页面
	 * @时间: 2017年10月24日 下午6:04:54
	 * @author: Guopeng
	 * @return mixed
	 */
	public function create(){
		$this->display();
	}

	/**
	 * 添加问题分类
	 * @时间: 2017年10月24日 下午6:04:54
	 * @author: Guopeng
	 * @return mixed
	 */
	public function recording(){
		$request = request();
		$res = $this->respository->create($request);
		//返回结果
		if($res === false){
			$msg = $this->model->getError().'添加失败，请重试！';
			if(IS_AJAX){
				$this->error($msg,'',true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = '添加成功';
			$url = U('ProblemType/index');
			if(IS_AJAX){
				$this->success($msg,$url,true);
			}else{
				$this->success($msg,$url);
			}
		}
	}
	
	/**
	 * 更新问题分类页面
	 * @时间: 2017年10月24日 下午6:04:54
	 * @author: Guopeng
	 */
	public function update(){
		$id = request()['id'] + 0;
		$entity = $this->respository->firstOrFalse(['id' => ['eq',$id]]);
		if(!$entity){
			$this->error('参数有误，没有该分类的相关信息！');
			die;
		}
		$this->assign(['entity' => $entity]);
		$this->display();
	}
	
	/**
	 * 更新问题分类信息
	 * @时间: 2017年10月24日 下午6:04:54
	 * @author: Guopeng
	 */
	public function store(){
		//取参数
		$request = request();
		$id = $request['id'];
		unset($request['id']);
		$data = $request;
		//更新操作
		$res = $this->respository->update($data,$id,'id');
		//返回结果
		if($res === false){
			$msg = $this->model->getError().'更新分类失败，请重试！';
			if(IS_AJAX){
				$this->error($msg,'',true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = '更新分类成功';
			$url = U('ProblemType/index');
			if(IS_AJAX){
				$this->success($msg,$url,true);
			}else{
				$this->success($msg,$url);
			}
		}
	}
	
	/**
	 * 删除分类
	 * @时间: 2017年10月24日 下午6:04:54
	 * @author: Guopeng
	 */
	public function erase(){
		//取参数
		$request = request();
		$id = $request['id'] + 0;
		//删除业务操作
		$res = $this->respository->delete(['id' => ['eq',$id]]);
		//返回结果
		if($res == 0){
			$msg = $this->model->getError();
			if(IS_AJAX){
				$this->error($msg,'',true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = '删除成功';
			if(IS_AJAX){
				$this->success($msg,'',true);
			}else{
				$this->success($msg);
			}
		}
	}
	
}